msg!() { /* proc-macro */ }Expand description
Creates a DiagMessage from an inline Fluent pattern. The pattern is checked to be valid
Fluent, but variables are not checked against the arguments set on the diagnostic.
msg!() { /* proc-macro */ }Creates a DiagMessage from an inline Fluent pattern. The pattern is checked to be valid
Fluent, but variables are not checked against the arguments set on the diagnostic.